==> not-so-tuf-0.2.7.tar.gz: not-so-tuf-0.2.7/cli/ui_utils.py <==
# The MIT License (MIT)
#
# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import logging
import os
import platform
import shlex
import struct
import subprocess
import sys

from not_so_tuf.version import __version__

log = logging.getLogger(__name__)

# If i didn't check for platform before
# importing i'd get an ImportError
if sys.platform == 'win32':
    import msvcrt
    clear = 'cls'
else:
    import tty
    import termios
    clear = 'clear'


# Takes a string and adds it to the menu header along side
# the app name.
def app_header(*args, **kwargs):
    try:
        page = args[0]
    except IndexError:
        page = ""
    window_size = get_terminal_size()[0]

    def add_style():
        app = 'Not so TUF v{}'.format(__version__)
        top = '*' * window_size + '\n'
        bottom = '\n' + '*' * window_size + '\n'
        if len(page) > 1:
            header = app + ' - ' + page
        else:
            header = app + page
        header = header.center(window_size)
        msg = top + header + bottom
        return msg
    os.system(clear)
    return add_style()


# Gets a single character form standard input. Does not echo to the screen
class _Getch:

    def __init__(self):
        if sys.platform == 'win32':
            self.impl = _GetchWindows()
        else:
            self.impl = _GetchUnix()

    def __call__(self):
        return self.impl()


class _GetchUnix:
    def __init__(self):
        # Not sure if these imports are required here
        # import tty, sys
        pass

    def __call__(self):
        # NOt sure if these imports are required here
        # import tty, termios
        pass
        fd = sys.stdin.fileno()
        old_settings = termios.tcgetattr(fd)
        try:
            tty.setraw(sys.stdin.fileno())
            ch = sys.stdin.read(1)
        finally:
            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
        return ch


class _GetchWindows:
    def __init__(self):
        # Not sure if this import is required
        # import msvcrt
        pass

    def __call__(self):
        # Not sure if this import is required
        # import msvcrt
        return msvcrt.getch()


# Takes a string and retuns a string formatted
# to the center of the terminal window.
def format_msg(*args):
    window_size = get_terminal_size()[0]

    def fix():
        formatted = []
        finished = ['\n']
        count = 0
        words = args[0].split(' ')
        for w in words:
            w = w + ' '
            if count + len(w) > window_size / 2:
                finished.append(''.join(formatted).center(window_size))
                finished.append('\n')
                count = len(w)
                formatted = []
                formatted.append(w)
            else:
                formatted.append(w)
                count += len(w)
        finished.append(''.join(formatted).center(window_size))
        finished.append('\n')
        return ''.join(finished)
    return fix()


# Takes a list of tuples(menu_name, call_back) adds menu numbers
# then prints menu to screen.
# Gets input from user, then returns the callback
def menu_options(*args):
    if len(args) != 1:
        return ""
    if not isinstance(args[0], list):
        return ""

    def add_options():
        getch = _Getch()
        menu = []
        count = 1
        for s in args[0]:
            item = '{}. {}\n'.format(count, s[0])
            menu.append(item)
            count += 1
        print ''.join(menu)
        answers = []
        for a in xrange(1, len(menu) + 1):
            answers.append(str(a))
        while 1:
            ans = getch()
            if ans in answers:
                break
            else:
                log.debug('Not an acceptable answer!')
        return args[0][int(ans) - 1][1]
    return add_options()



# get width and height of console
# works on linux, os x, windows, cygwin(windows)
# originally retrieved from:
# http://stackoverflow.com/questions/
# 566746/how-to-get-console-window-width-in-python
def get_terminal_size():
    current_os = platform.system()
    tuple_xy = None
    if current_os == 'Windows':
        tuple_xy = _get_terminal_size_windows()
        if tuple_xy is None:
            tuple_xy = _get_terminal_size_tput()
            # needed for window's python in cygwin's xterm!
    if current_os in ['Linux', 'Darwin'] or current_os.startswith('CYGWIN'):
        tuple_xy = _get_terminal_size_linux()
    if tuple_xy is None:
        print "default"
        tuple_xy = (80, 25)      # default value
    return tuple_xy


def _get_terminal_size_windows():
    try:
        from ctypes import windll, create_string_buffer
        # stdin handle is -10
        # stdout handle is -11
        # stderr handle is -12
        h = windll.kernel32.GetStdHandle(-12)
        csbi = create_string_buffer(22)
        res = windll.kernel32.GetConsoleScreenBufferInfo(h, csbi)
        if res:
            (bufx, bufy, curx, cury, wattr,
             left, top, right, bottom,
             maxx, maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
            sizex = right - left + 1
            sizey = bottom - top + 1
            return sizex, sizey
    except:
        pass


def _get_terminal_size_tput():
    # get terminal width
    # src: http://stackoverflow.com/questions/263890/how-do-i-find-the-width-height-of-a-terminal-window
    try:
        cols = int(subprocess.check_call(shlex.split('tput cols')))
        rows = int(subprocess.check_call(shlex.split('tput lines')))
        return (cols, rows)
    except:
        pass


def _get_terminal_size_linux():
    def ioctl_GWINSZ(fd):
        try:
            import fcntl
            # Is this required
            # import termios
            cr = struct.unpack('hh',
                               fcntl.ioctl(fd, termios.TIOCGWINSZ, '1234'))
            return cr
        except:
            pass
    cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
    if not cr:
        try:
            fd = os.open(os.ctermid(), os.O_RDONLY)
            cr = ioctl_GWINSZ(fd)
            os.close(fd)
        except:
            pass
    if not cr:
        try:
            cr = (os.environ['LINES'], os.environ['COLUMNS'])
        except:
            return None
    return int(cr[1]), int(cr[0])

==> not-so-tuf-0.3.2.tar.gz: not-so-tuf-0.3.2/cli/ui_utils.py <==
# The MIT License (MIT)
#
# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import logging
import os
import platform
import shlex
import struct
import subprocess
import sys

from not_so_tuf.compat import print_function
from not_so_tuf.version import __version__

log = logging.getLogger(__name__)

# If i didn't check for platform before
# importing i'd get an ImportError
if sys.platform == 'win32':
    import msvcrt
    clear = 'cls'
else:
    import tty
    import termios
    clear = 'clear'


# Takes a string and adds it to the menu header along side
# the app name.
def app_header(*args, **kwargs):
    try:
        page = args[0]
    except IndexError:
        page = ""
    window_size = get_terminal_size()[0]

    def add_style():
        app = 'Not so TUF v{}'.format(__version__)
        top = '*' * window_size + '\n'
        bottom = '\n' + '*' * window_size + '\n'
        if len(page) > 1:
            header = app + ' - ' + page
        else:
            header = app + page
        header = header.center(window_size)
        msg = top + header + bottom
        return msg
    os.system(clear)
    return add_style()


# Gets a single character form standard input. Does not echo to the screen
class _Getch:

    def __init__(self):
        if sys.platform == 'win32':
            self.impl = _GetchWindows()
        else:
            self.impl = _GetchUnix()

    def __call__(self):
        return self.impl()


class _GetchUnix:
    def __init__(self):
        # Not sure if these imports are required here
        # import tty, sys
        pass

    def __call__(self):
        # NOt sure if these imports are required here
        # import tty, termios
        pass
        fd = sys.stdin.fileno()
        old_settings = termios.tcgetattr(fd)
        try:
            tty.setraw(sys.stdin.fileno())
            ch = sys.stdin.read(1)
        finally:
            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
        return ch


class _GetchWindows:
    def __init__(self):
        # Not sure if this import is required
        # import msvcrt
        pass

    def __call__(self):
        # Not sure if this import is required
        # import msvcrt
        return msvcrt.getch()


# Takes a string and retuns a string formatted
# to the center of the terminal window.
def format_msg(*args):
    window_size = get_terminal_size()[0]

    def fix():
        formatted = []
        finished = ['\n']
        count = 0
        words = args[0].split(' ')
        for w in words:
            w = w + ' '
            if count + len(w) > window_size / 2:
                finished.append(''.join(formatted).center(window_size))
                finished.append('\n')
                count = len(w)
                formatted = []
                formatted.append(w)
            else:
                formatted.append(w)
                count += len(w)
        finished.append(''.join(formatted).center(window_size))
        finished.append('\n')
        return ''.join(finished)
    return fix()


# Takes a list of tuples(menu_name, call_back) adds menu numbers
# then prints menu to screen.
# Gets input from user, then returns the callback
def menu_options(*args):
    if len(args) != 1:
        return ""
    if not isinstance(args[0], list):
        return ""

    def add_options():
        getch = _Getch()
        menu = []
        count = 1
        for s in args[0]:
            item = '{}. {}\n'.format(count, s[0])
            menu.append(item)
            count += 1
        print(''.join(menu))
        answers = []
        for a in xrange(1, len(menu) + 1):
            answers.append(str(a))
        while 1:
            ans = getch()
            if ans in answers:
                break
            else:
                log.debug('Not an acceptable answer!')
        return args[0][int(ans) - 1][1]
    return add_options()



# get width and height of console
# works on linux, os x, windows, cygwin(windows)
# originally retrieved from:
# http://stackoverflow.com/questions/
# 566746/how-to-get-console-window-width-in-python
def get_terminal_size():
    current_os = platform.system()
    tuple_xy = None
    if current_os == 'Windows':
        tuple_xy = _get_terminal_size_windows()
        if tuple_xy is None:
            tuple_xy = _get_terminal_size_tput()
            # needed for window's python in cygwin's xterm!
    if current_os in ['Linux', 'Darwin'] or current_os.startswith('CYGWIN'):
        tuple_xy = _get_terminal_size_linux()
    if tuple_xy is None:
        print_function("default")
        tuple_xy = (80, 25)      # default value
    return tuple_xy


def _get_terminal_size_windows():
    try:
        from ctypes import windll, create_string_buffer
        # stdin handle is -10
        # stdout handle is -11
        # stderr handle is -12
        h = windll.kernel32.GetStdHandle(-12)
        csbi = create_string_buffer(22)
        res = windll.kernel32.GetConsoleScreenBufferInfo(h, csbi)
        if res:
            (bufx, bufy, curx, cury, wattr,
             left, top, right, bottom,
             maxx, maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
            sizex = right - left + 1
            sizey = bottom - top + 1
            return sizex, sizey
    except:
        pass


def _get_terminal_size_tput():
    # get terminal width
    # src: http://stackoverflow.com/questions/263890/how-do-i-find-the-width-height-of-a-terminal-window
    try:
        cols = int(subprocess.check_call(shlex.split('tput cols')))
        rows = int(subprocess.check_call(shlex.split('tput lines')))
        return (cols, rows)
    except:
        pass


def _get_terminal_size_linux():
    def ioctl_GWINSZ(fd):
        try:
            import fcntl
            # Is this required
            # import termios
            cr = struct.unpack('hh',
                               fcntl.ioctl(fd, termios.TIOCGWINSZ, '1234'))
            return cr
        except:
            pass
    cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
    if not cr:
        try:
            fd = os.open(os.ctermid(), os.O_RDONLY)
            cr = ioctl_GWINSZ(fd)
            os.close(fd)
        except:
            pass
    if not cr:
        try:
            cr = (os.environ['LINES'], os.environ['COLUMNS'])
        except:
            return None
    return int(cr[1]), int(cr[0])
